@@ -10,7 +10,7 @@ use Rose::DB::Object::MakeMethods::Date;
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.70';
+our $VERSION = '0.771';
 
 __PACKAGE__->add_common_method_maker_argument_names('default', 'time_zone', 'type');
 
@@ -31,8 +31,9 @@ sub type { 'date' }
 sub should_inline_value
 {
   #my($self, $db, $value) = @_;
-  return ($_[1]->validate_date_keyword($_[2]) && 
-          ($_[1]->driver eq 'informix' || $_[2] =~ /^\w+\(.*\)$/)) ? 1 : 0;
+  no warnings 'uninitialized';
+  return (($_[1]->validate_date_keyword($_[2]) && $_[1]->should_inline_date_keywords) || 
+          $_[2] =~ /^\w+\(.*\)$/) ? 1 : 0;
 }
 
 sub method_should_set
